@@ -52,6 +52,7 @@ struct Message {
     QString contentLocation;
     QDateTime expires;
     int size = 0;
+    QString tapbacks;
 };
 Q_DECLARE_METATYPE(Message)
 
@@ -60,6 +61,8 @@ struct Chat {
     QDateTime lastContacted;
     QString lastMessage;
     int unreadMessages;
+    bool lastSentByMe;
+    QString lastAttachment;
 };
 Q_DECLARE_METATYPE(Chat)
 
@@ -73,18 +76,19 @@ public:
     // Messages
     void addMessage(const Message &message);
     void deleteMessage(const QString &id);
-    QVector<Message> messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id = QString()) const;
+    QVector<Message> messagesForNumber(const PhoneNumberList &phoneNumberList, const QString &id = QString(), const bool last = false) const;
     void updateMessageDeliveryState(const QString &id, const MessageState state);
     void updateMessageSent(const QString &id, const QString &messageId, const QString &contentLocation);
     void updateMessageDeliveryReport(const QString &messageId);
     void updateMessageReadReport(const QString &messageId, const PhoneNumber &fromNumber);
     void markMessageRead(const int id);
+    void updateMessageTapbacks(const QString &id, const QString tapbacks);
+    QString lastMessageWithText(const PhoneNumberList &phoneNumberList, const QString &text);
+    QString lastMessageWithAttachment(const PhoneNumberList &phoneNumberList);
 
     // Chats
     QVector<Chat> chats() const;
     int unreadMessagesForNumber(const PhoneNumberList &phoneNumberList) const;
-    QString lastMessageForNumber(const PhoneNumberList &phoneNumberList) const;
-    QDateTime lastContactedForNumber(const PhoneNumberList &phoneNumberList) const;
     void markChatAsRead(const PhoneNumberList &phoneNumberList);
     void deleteChat(const PhoneNumberList &phoneNumberList);
 
@@ -98,6 +102,8 @@ private:
     void migrationV3(uint current);
     void migrationV4(uint current);
     void migrationV5(uint current);
+    void migrationV6(uint current);
+    void migrationV7(uint current);
     void migrate();
 
     QSqlDatabase m_database;
