@@ -6,12 +6,10 @@
 
 #include <functional>
 
-#include <QDBusArgument>
-#include <QDebug>
-#include <QSharedDataPointer>
 #include <QString>
-
-#include <global.h>
+#include <QSharedDataPointer>
+#include <QDebug>
+#include <QDBusArgument>
 
 struct PhoneNumberPrivate;
 
@@ -37,23 +35,17 @@ public:
     QString toNational() const;
     QString toE164() const;
     bool isValid() const;
-    static void setCountryCode(const QString &countryCode);
-
-    QString toString() const;
 
 private:
     QSharedDataPointer<PhoneNumberPrivate> d;
-    static std::string countryCode;
 };
 
-inline QDebug &operator<<(QDebug &debug, const PhoneNumber &phoneNumber)
-{
+inline QDebug &operator<<(QDebug &debug, const PhoneNumber &phoneNumber) {
     return debug << phoneNumber.toInternational();
 }
 
-inline uint qHash(const PhoneNumber &phoneNum)
-{
-    return hash(phoneNum.toInternational());
+inline uint qHash(const PhoneNumber &phoneNum) {
+    return qHash(phoneNum.toInternational());
 }
 
 Q_DECLARE_METATYPE(PhoneNumber)
