@@ -5,30 +5,26 @@
 
 #include "channelhandler.h"
 
-#include <KLocalizedString>
-
 #include "utils.h"
 #include "databasethread.h"
+#include "modemcontroller.h"
+
 #include <global.h>
 #include <database.h>
 
 ChannelHandler::ChannelHandler(std::optional<QString> &modemPath, QObject *parent)
     : QObject(parent)
 {
-    if (modemPath.has_value()) {
-        m_msgManager.setModemPath(*modemPath);
-    } else {
-        connect(&m_manager, &QOfonoManager::defaultModemChanged, this, [&] {
-            m_msgManager.setModemPath(m_manager.defaultModem());
-        });
+    ModemController::instance().init(modemPath);
 
-        m_msgManager.setModemPath(m_manager.defaultModem());
-    }
+    // daemon dbus interface
+    m_interface = new org::kde::spacebar::Daemon(QStringLiteral("org.kde.Spacebar"), QStringLiteral("/Daemon"), QDBusConnection::sessionBus(), this);
 
     // Refresh chat list when message arrives
     // The message will be saved by the background daemon
-    connect(&m_msgManager, &QOfonoMessageManager::incomingMessage, this, [&](const QString &, const QVariantMap &info) {
-        Q_EMIT m_databaseThread.database().messagesChanged(info[SL("Sender")].toString());
+    connect(m_interface, &OrgKdeSpacebarDaemonInterface::messageAdded, [this](const QString &phoneNumber, const QString &id) {
+        Q_UNUSED(id);
+        Q_EMIT m_databaseThread.database().messagesChanged(PhoneNumberList(phoneNumber));
     });
 }
 
@@ -37,7 +33,12 @@ AsyncDatabase &ChannelHandler::database()
     return m_databaseThread.database();
 }
 
-MessageManager &ChannelHandler::msgManager()
+org::kde::spacebar::Daemon *ChannelHandler::interface()
 {
-    return m_msgManager;
+    return m_interface;
+}
+
+Mms &ChannelHandler::mms()
+{
+    return m_mms;
 }
