@@ -11,6 +11,8 @@
 #include <QStandardPaths>
 #include <QQmlApplicationEngine>
 
+#include <QCoroFuture>
+
 #include <KLocalizedString>
 #include <KPeople/PersonData>
 
@@ -41,7 +43,7 @@ ChatListModel::ChatListModel(ChannelHandler &handler, QObject *parent)
         }
     });
 
-    connectFuture(m_handler.database().chats(), this, &ChatListModel::updateChats);
+    fetchChats();
 
     Q_EMIT m_handler.interface()->disableNotificationsForNumber(QString());
 }
@@ -59,6 +61,8 @@ QHash<int, QByteArray> ChatListModel::roleNames() const
         {Role::LastContactedRole, BL("lastContacted")},
         {Role::UnreadMessagesRole, BL("unreadMessages")},
         {Role::LastMessageRole, BL("lastMessage")},
+        {Role::LastSentByMeRole, BL("lastSentByMe")},
+        {Role::LastAttachmentRole, BL("lastAttachment")},
         {Role::IsContactRole, BL("isContact")},
     };
 }
@@ -84,7 +88,7 @@ QVariant ChatListModel::data(const QModelIndex &index, int role) const
                 if (name.isEmpty()) {
                     name = number.toNational();
                     if (name == SL("0")) {
-                        name = i18n("Unknown");
+                        name = i18nc("Invalid phone number", "Unknown");
                     }
                 }
                 names.append(name);
@@ -106,6 +110,10 @@ QVariant ChatListModel::data(const QModelIndex &index, int role) const
         return m_chats.at(index.row()).unreadMessages;
     case LastMessageRole:
         return m_chats.at(index.row()).lastMessage;
+    case LastSentByMeRole:
+        return m_chats.at(index.row()).lastSentByMe;
+    case LastAttachmentRole:
+        return m_chats.at(index.row()).lastAttachment;
     case IsContactRole:
         return phoneNumberList.size() == 1 && !KPeople::PersonData(m_mapper.uriForNumber(phoneNumberList.first())).name().isEmpty();
     }
@@ -134,7 +142,21 @@ void ChatListModel::markChatAsRead(const PhoneNumberList &phoneNumberList)
 
 void ChatListModel::fetchChats()
 {
-    connectFuture(m_handler.database().chats(), this, &ChatListModel::updateChats);
+    fetchChatsInternal();
+}
+
+QCoro::Task<void> ChatListModel::fetchChatsInternal()
+{
+    const auto chats = co_await m_handler.database().chats();
+
+    beginResetModel();
+    m_chats = chats;
+    // Sort chat list by most recent chat
+    std::sort(m_chats.begin(), m_chats.end(), [](const Chat &a, const Chat &b) -> bool {
+        return a.lastContacted > b.lastContacted;
+    });
+    endResetModel();
+    Q_EMIT chatsFetched();
 }
 
 void ChatListModel::deleteChat(const PhoneNumberList &phoneNumberList)
@@ -146,19 +168,6 @@ void ChatListModel::deleteChat(const PhoneNumberList &phoneNumberList)
     dir.removeRecursively();
 }
 
-void ChatListModel::updateChats(const QVector<Chat> &chats)
-{
-    beginResetModel();
-    m_chats = chats;
-    // Sort chat list by most recent chat
-    std::sort(m_chats.begin(), m_chats.end(), [](const Chat & a, const Chat & b) -> bool
-    {
-        return a.lastContacted > b.lastContacted;
-    });
-    endResetModel();
-    Q_EMIT chatsFetched();
-}
-
 void ChatListModel::restoreDefaults()
 {
     SettingsManager::self()->setDefaults();
@@ -169,3 +178,9 @@ void ChatListModel::saveSettings()
     SettingsManager::self()->save();
     Q_EMIT m_handler.interface()->syncSettings();
 }
+
+QString ChatListModel::attachmentsFolder(const PhoneNumberList &phoneNumberList) const
+{
+    const QString folder = QString::number(qHash(phoneNumberList.toString()));
+    return QStandardPaths::writableLocation(QStandardPaths::GenericDataLocation) + SL("/spacebar/attachments/") + folder;
+}
