@@ -53,7 +53,8 @@ public:
         ContentLocationRole,
         ExpiresRole,
         ExpiresDateTimeRole,
-        SizeRole
+        SizeRole,
+        TapbacksRole
     };
     Q_ENUM(Role)
 
@@ -89,6 +90,15 @@ public:
      */
     void addMessage(const Message &message);
 
+    /**
+     * @brief adds a tapack reaction to a previously sent or recieved message,
+     * and updates the model and database
+     * @param id
+     * @param tapback
+     * @param isRemoved
+     */
+    Q_INVOKABLE void sendTapback(const QString &id, const QString &tapback, const bool &isRemoved);
+
     /**
      * @brief sends a message with the specified text,
      * and adds it to the model and database by calling addMessage(const QString&)
@@ -137,8 +147,10 @@ private:
     QVector<Person> m_peopleData;
 
 private Q_SLOTS:
+    QCoro::Task<void> fetchMessages(const QString &id);
+    QCoro::Task<void> fetchUpdatedMessage(const QString &id);
     void messageAdded(const QString &numbers, const QString &id);
-    void updateModel(const QVector<Message> &messages);
+    void messageUpdated(const QString &numbers, const QString &id);
 
 Q_SIGNALS:
     void phoneNumberListChanged();
